@@ -1,6 +1,4 @@
-#![doc(
-    html_logo_url = "https://raw.githubusercontent.com/EpicEric/duper/refs/heads/main/logos/duper-100-100.png"
-)]
+#![doc(html_logo_url = "https://duper.dev.br/logos/duper-100-100.png")]
 //! # Duper
 //!
 //! The format that's super!
